@@ -15,7 +15,7 @@ import base64
 import hashlib
 import os
 
-from manta import PrivateKeySigner, MantaClient
+from manta import PrivateKeySigner, MantaClient, errors
 
 
 class Storage(driver.Base):
@@ -54,7 +54,7 @@ class Storage(driver.Base):
 
         methods = [m for m in [content, path, file] if m is not None]
         if len(methods) != 1:
-            raise self.client.errors.MantaError("exactly one of 'content', 'path' or "
+            raise errors.MantaError("exactly one of 'content', 'path' or "
                 "'file' must be provided")
         if content is not None:
             pass
@@ -67,7 +67,7 @@ class Storage(driver.Base):
         else:
             content = file.read()
         if not isinstance(content, bytes):
-            raise self.client.errors.MantaError("'content' must be bytes, not unicode")
+            raise errors.MantaError("'content' must be bytes, not unicode")
 
         headers["Content-Length"] = str(len(content))
         md5 = hashlib.md5(content)
@@ -75,7 +75,7 @@ class Storage(driver.Base):
         res, content = self.client._request(mpath, "PUT", body=content,
                                      headers=headers)
         if res["status"] != "204":
-            raise self.client.errors.MantaAPIError(res, content)
+            raise errors.MantaAPIError(res, content)
 
     def put_directory(self, mdir):
         headers = {
@@ -87,7 +87,7 @@ class Storage(driver.Base):
 
         res, content = self.client._request(mdir, "PUT", headers=headers)
         if res["status"] != "204":
-            raise self.client.errors.MantaAPIError(res, content)
+            raise errors.MantaAPIError(res, content)
 
     def mkdirp(self, mpath):
 
@@ -127,9 +127,14 @@ class Storage(driver.Base):
 
     def exists(self, path):
         mpath = self.create_manta_path(path)
-        res, status = self.client._request(path=mpath, method='HEAD')
+        res, content = self.client._request(path=mpath, method='HEAD')
         return str(res.status) != '404'
 
+    def get_size(self, path):
+        mpath = self.create_manta_path(path)
+        res, content = self.client._request(path=mpath, method='HEAD')
+        return int(res["content-length"])
+
     def stream_write(self, path, fp):
         mpath = self.create_manta_path(path)
         self.mkdirp(os.path.dirname(mpath))
